@@ -215,7 +215,7 @@ class CfnFileSystem(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any) -> "CfnFileSystem":
+    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any, *, finder: aws_cdk.core.ICfnFinder) -> "CfnFileSystem":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -223,11 +223,14 @@ class CfnFileSystem(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type
         :param scope: -
         :param id: -
         :param resource_attributes: -
+        :param finder: The finder interface used to resolve references across the template.
 
         stability
         :stability: experimental
         """
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes])
+        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
+
+        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
